//
//  XSPEC12  November 2003
//
//
#include <XSUser/Global/XSGlobal.h>
#include <XSUser/Global/Global.h>
#include <XSUtil/Utils/XSutility.h>
#include <xsTypes.h>
#include <XSstreams.h>


int 
XSGlobal::xsInitpackage(ClientData cdata,Tcl_Interp* tclInterp,int objc, Tcl_Obj* CONST  objv[])
{
   string cmd = string(static_cast<char*>(cdata));
   string shscript = "xspackage";
   if ( objc < 3 )
   {
      XSGlobal::printDocs(static_cast<char*>(cdata),"?");      
      return globalData->autoSave(TCL_ERROR);
   }
   else
   {
#ifdef __CYGWIN__
   tcerr << "\n***Error: Initpackage cannot be run inside XSPEC on CYGWIN.\n"
         << "   See the initpackage help to use the static_initpackage,\n"
         << "   command for building and linking static local model libraries."
         << std::endl;
   return globalData->autoSave(TCL_ERROR); 
#endif
      string lc(Tcl_GetString(objv[1]));
      lc = XSutility::lowerCase(lc);
      if (lc == string("static_local_mods"))
      {
         tcerr << "\n***Error: Initpackage will only build static libraries\n"
               << "   when run as a stand-alone application outside of XSPEC."
               << std::endl;
         return globalData->autoSave(TCL_ERROR);
      }
      string initCmd(shscript);
      initCmd +=  string(" ") + Tcl_GetString(objv[1]);
      initCmd +=  string(" ") + Tcl_GetString(objv[2]) + string(" ");
      string buildDir;
      const string UDMGET("-udmget");
      bool isUdmget = false;
      if ( objc == 3 )
      {
         buildDir = globalData->defaultLocalModelDirectory();       
      }
      else
      {
         // 3rd argument may be the local model dir or the "-udmget" flag
         // If it's the latter, we must insert the default directory 
         // prior to it.
         lc = string(Tcl_GetString(objv[3]));
         lc = XSutility::lowerCase(lc);
         if (lc.length() > 1 && UDMGET.find(lc) == 0)
         {
            buildDir = globalData->defaultLocalModelDirectory();
            isUdmget = true;
         }
         else 
            buildDir =  Tcl_GetString(objv[3]); 
              
      }
      initCmd += buildDir;
      if (isUdmget)
      {
         initCmd += string(" ") + UDMGET;
      }
      
      // The "-udmget" flag may also appear as an optional 4th argument
      if (objc > 4)
      {
         // Not going to check what the 4th arg actual is.  Simply 
         // append it and pass along to xspackage.
         initCmd += string(" ") + Tcl_GetString(objv[4]);
      }
      
      if (!system(initCmd.c_str())) 
      {
         tcout <<"\nLocal model library has been built from model definition and code files in:\n"
            << buildDir <<"\n" << std::endl;
         return globalData->autoSave(TCL_OK);
      }
      else return globalData->autoSave(TCL_ERROR);
   }
}
